Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var EventsCounter = prometheus.NewCounterVec( prometheus.CounterOpts{ Name: "aws_service_events", Help: "This metric indicates on whats happening on various aws services, e.g RDS", }, []string{"event_id", "event_message", "event_source"}, )
Functions ¶
Types ¶
type Message ¶
type Message struct {
Message json.RawMessage `json:"Message"`
MessageID string `json:"MessageId"`
TopicArn string `json:"TopicArn"`
MessageType string `json:"Type"`
}
type MessageProcessor ¶
type MessageProcessor struct {
// contains filtered or unexported fields
}
type RdsEventMessage ¶
type RdsEventMessage struct {
EventSource string `json:"Event Source"`
EventTime string `json:"Event Time"`
IdentifierLink string `json:"Identifier Link"`
SourceID string `json:"Source ID"`
SourceARN string `json:"Source ARN"`
EventID string `json:"Event ID"`
EventMessage string `json:"Event Message"`
}
RdsEventMessage is a AWS RDS Events Message template which needs to parse from SQS queues
Click to show internal directories.
Click to hide internal directories.